@@ -9,6 +9,7 @@ from sqlalchemy.orm import mapped_column, Mapped, validates
 
 from arpakitlib.ar_datetime_util import now_utc_dt
 from arpakitlib.ar_sqlalchemy_util import get_string_info_from_declarative_base, BaseDBM
+from arpakitlib.ar_str_util import make_none_if_blank
 
 
 def generate_default_long_id() -> str:
@@ -45,6 +46,7 @@ class SimpleDBM(BaseDBM):
         uuid = "uuid"
         slug = "slug"
         creation_dt = "creation_dt"
+        private_comment = "private_comment"
         detail_data = "detail_data"
         extra_data = "extra_data"
 
@@ -53,7 +55,7 @@ class SimpleDBM(BaseDBM):
         nullable=False,
         primary_key=True,
         autoincrement=True,
-        sort_order=-103,
+        sort_order=-104,
     )
     long_id: Mapped[str] = mapped_column(
         sqlalchemy.TEXT,
@@ -61,7 +63,7 @@ class SimpleDBM(BaseDBM):
         unique=True,
         insert_default=generate_default_long_id,
         server_default=func.gen_random_uuid(),
-        sort_order=-102,
+        sort_order=-103,
     )
     uuid: Mapped[sqlalchemy.dialects.postgresql.UUID] = mapped_column(
         sqlalchemy.UUID(as_uuid=True),
@@ -85,7 +87,11 @@ class SimpleDBM(BaseDBM):
         server_default=func.now(),
         sort_order=-100,
     )
-    extra_data: Mapped[dict[str, Any]] = mapped_column(
+    private_comment: Mapped[str | None] = mapped_column(
+        sqlalchemy.TEXT,
+        nullable=True,
+    )
+    detail_data: Mapped[dict[str, Any]] = mapped_column(
         sqlalchemy.JSON,
         nullable=False,
         index=False,
@@ -93,6 +99,14 @@ class SimpleDBM(BaseDBM):
         server_default="{}",
         sort_order=1000,
     )
+    extra_data: Mapped[dict[str, Any]] = mapped_column(
+        sqlalchemy.JSON,
+        nullable=False,
+        index=False,
+        insert_default={},
+        server_default="{}",
+        sort_order=1001,
+    )
 
     def __repr__(self) -> str:
         parts = [f"id={self.id}"]
@@ -100,6 +114,8 @@ class SimpleDBM(BaseDBM):
             parts.append(f"slug={self.slug}")
         return f"{self.entity_name} ({', '.join(parts)})"
 
+    # ---validators---
+
     @validates("slug")
     def _validate_slug(self, key, value, *args, **kwargs):
         if value is None:
@@ -111,6 +127,23 @@ class SimpleDBM(BaseDBM):
             raise ValueError(f"{key=}, {value=}, value contains spaces")
         return value
 
+    @validates("private_comment")
+    def _validate_private_comment(self, key, value, *args, **kwargs):
+        if value is None:
+            return None
+        if not isinstance(value, str):
+            raise ValueError(f"{key=}, {value=}, value is not str")
+        value = make_none_if_blank(value.strip())
+        return value
+
+    @validates("detail_data")
+    def _validate_detail_data(self, key, value, *args, **kwargs):
+        if value is None:
+            value = {}
+        if not isinstance(value, dict):
+            raise ValueError(f"{key=}, {value=}, value is not dict")
+        return value
+
     @validates("extra_data")
     def _validate_extra_data(self, key, value, *args, **kwargs):
         if value is None:
@@ -119,10 +152,16 @@ class SimpleDBM(BaseDBM):
             raise ValueError(f"{key=}, {value=}, value is not dict")
         return value
 
+    # ---more---
+
     @property
     def id_and_long_id(self) -> str:
         return f"{self.id}--{self.long_id}"
 
+    @property
+    def id_and_long_id_and_uuid(self) -> str:
+        return f"{self.id}--{self.long_id}--{str(self.uuid)}"
+
     @classmethod
     def get_cls_entity_name(cls) -> str:
         return cls.__name__.removesuffix("DBM")
@@ -143,19 +182,23 @@ class SimpleDBM(BaseDBM):
     def uuid_as_str(self) -> str:
         return str(self.uuid)
 
-    @classmethod
-    def get_mapped_column_names(cls) -> list[str]:
-        return [k for k, v in SimpleDBM.__dict__.items() if isinstance(v, Mapped)]
-
     # ---SDP---
 
+    @property
+    def sdp_entity_name(self) -> str:
+        return self.entity_name
+
+    @property
+    def sdp_entity_name_plural(self) -> str:
+        return self.entity_name_plural
+
     @property
     def sdp_id_and_long_id(self) -> str:
         return self.id_and_long_id
 
     @property
-    def sdp_entity_name(self) -> str:
-        return self.entity_name
+    def sdp_id_and_long_id_and_uuid(self) -> str:
+        return self.id_and_long_id_and_uuid
 
 
 def get_simple_dbm_class() -> type[SimpleDBM]:
